@@ -6,14 +6,14 @@ use base qw(Class::Accessor);
 use File::Temp qw(tempdir);
 use File::Spec::Functions qw(catfile catdir splitpath);
 use File::Copy;
-use Archive::Any;
+use Archive::Any::Lite;
 use Carp;
 use Module::CPANTS::Kwalitee;
 use IO::Capture::Stdout;
 use IO::Capture::Stderr;
-use YAML::Syck qw(LoadFile);
+use CPAN::DistnameInfo;
 
-use version; our $VERSION=version->new('0.85');
+our $VERSION = '0.88';
 
 # setup logger
 if (! main->can('logger')) {
@@ -39,6 +39,9 @@ sub new {
     main::logger("distro: $opts->{dist}");
 
     $me->mck(Module::CPANTS::Kwalitee->new);
+
+    # For Test::Kwalitee and friends
+    $me->d->{is_local_distribution} = 1 if -d $opts->{dist};
     
     unless ($me->opts->{no_capture} or $INC{'Test/More.pm'}) {
         my $cserr=IO::Capture::Stderr->new;
@@ -55,12 +58,33 @@ sub unpack {
     my $me=shift;
     return 'cant find dist' unless $me->dist;
 
+    my $di=CPAN::DistnameInfo->new($me->dist);
+    my ($major,$minor);
+    if ($di->version) {
+        ($major,$minor)=$di->version=~/^(\d+)\.(.*)/;
+    }
+    $major=0 unless defined($major);
+    my $ext=$di->extension || 'unknown';
+    
+    $me->d->{package}=$di->filename;
+    $me->d->{vname}=$di->distvname;
+    $me->d->{extension}=$ext;
+    $me->d->{version}=$di->version;
+    $me->d->{version_major}=$major;
+    $me->d->{version_minor}=$minor;
+    $me->d->{dist}=$di->dist;
+    $me->d->{author}=$di->cpanid;
+
+    unless($me->d->{package}) {
+        $me->d->{package}=$me->tarball;
+    }
+
     copy($me->dist,$me->testfile);
     $me->d->{size_packed}=-s $me->testfile;
     
     my $archive;
     eval {
-        $archive=Archive::Any->new($me->testfile);
+        $archive=Archive::Any::Lite->new($me->testfile);
         $archive->extract($me->testdir);
     };
 
@@ -84,7 +108,6 @@ sub unpack {
    
     opendir(my $fh_testdir,$me->testdir) || die "Cannot open ".$me->testdir.": $!";
     my @stuff=grep {/\w/} readdir($fh_testdir);
-    my $di=CPAN::DistnameInfo->new($me->dist);
 
     if (@stuff == 1) {
         $me->distdir(catdir($me->testdir,$stuff[0]));
@@ -157,7 +180,7 @@ q{Favourite record of the moment:
 
 __END__
 
-=pod
+=encoding UTF-8
 
 =head1 NAME
 
@@ -219,33 +242,32 @@ Reads the META.yml file and returns its content.
 
 =head1 WEBSITE
 
-http://cpants.perl.org/
+L<http://cpants.perl.org/>
 
 =head1 BUGS
 
 Please report any bugs or feature requests, or send any patches, to
 bug-module-cpants-analyse at rt.cpan.org, or through the web interface at
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-CPANTS-Analyse.
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-CPANTS-Analyse>.
 I will be notified, and then you'll automatically be notified of progress
 on your bug as I make changes.
 
 =head1 AUTHOR
 
-Thomas Klausner, <domm@cpan.org>, http://domm.zsi.at
+L<Thomas Klausner|https://metacpan.org/author/domm>
 
-Please use the perl-qa mailing list for discussing all things CPANTS:
-http://lists.perl.org/showlist.cgi?name=perl-qa
+Please use the C<perl-qa> mailing list for discussing all things CPANTS:
+L<http://lists.perl.org/list/perl-qa.html>
 
-Based on work by Leon Brocard <acme@astray.com> and the original idea
-proposed by Michael G. Schwern <schwern@pobox.com>
+Based on work by L<Léon Brocard|https://metacpan.org/author/lbrocard> and the
+original idea proposed by
+L<Michael G. Schwern|https://metacpan.org/author/schwern>.
 
 =head1 LICENSE
 
-This code is Copyright (c) 2003-2006 Thomas Klausner.
+This code is Copyright © 2003–2006
+L<Thomas Klausner|https://metacpan.org/author/domm>.
 All rights reserved.
 
 You may use and distribute this module according to the same terms
 that Perl is distributed under.
-
-=cut
-
