@@ -6,6 +6,8 @@ use base qw(Class::Accessor);
 use Module::Pluggable search_path=>['Module::CPANTS::Kwalitee'];
 use Carp;
 
+our $VERSION = '0.88';
+
 __PACKAGE__->mk_accessors(qw(generators _gencache _genhashcache _available _total));
 
 sub new {
@@ -125,7 +127,7 @@ q{Favourite record of the moment:
 
 __END__
 
-=pod
+=encoding UTF-8
 
 =head1 NAME
 
@@ -162,6 +164,10 @@ Get a list of core indicator names (NOT the whole indicator HASHREF).
 
 Get a list of optional indicator names (NOT the whole indicator HASHREF).
 
+=head3 experimental_indicator_names
+
+Get a list of experimental indicator names (NOT the whole indicator HASHREF).
+
 =head3 all_indicator_names
 
 Get a list of all indicator names (NOT the whole indicator HASHREF).
@@ -180,14 +186,11 @@ L<Module::CPANTS::Analyse>
 
 =head1 AUTHOR
 
-Thomas Klausner, <domm@cpan.org>, http://domm.zsi.at
+L<Thomas Klausner|https://metacpan.org/author/domm>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2006, 2009  Thomas Klausner
+Copyright © 2003–2006, 2009 L<Thomas Klausner|https://metacpan.org/author/domm>
 
 You may use and distribute this module according to the same terms
 that Perl is distributed under.
-
-=cut
-
